@@ -1,4 +1,4 @@
-as.folder.folderh <- function(x, ..., elt = names(x)[2], key = attr(x, "keys")[1]) {
+as.folder.folderh <- function(x, elt = names(x)[2], key = attr(x, "keys")[1], ...) {
   # Change an object x of class 'folderh' into an object of class 'folder'.
   # Each element of this 'folder' will be the rows of x corresponding to
   # a group, and the elements of the other columns of g.
